==> tecfy_core_package-0.1.17.tar.gz: lib/services/dynamic_links.dart <==
part of tecfy_core_client_package;

class DynamicLinksService{

  static init(){


  }
  
  static Future shareString(String message){
    // return Share.share(message);
  }

  static Future<String> retrieveDynamicLink() async {
    // final PendingDynamicLinkData data = await FirebaseDynamicLinks.instance.retrieveDynamicLink();
    // final Uri deepLink = data?.link;

    // return deepLink.path;
    // if (deepLink != null) {
    //   Navigator.pushNamed(context, deepLink.path); // deeplink.path == '/helloworld'
    // }
  }

  static Future<String> generateShortLinkList(String title,String message, String type, String id) async{
    // final DynamicLinkParameters parameters = new DynamicLinkParameters(
    //   domain: 'wis.page.link',
    //   link: Uri.parse('https://www.wishooo.com/list?id=$id'),
    //   androidParameters: new AndroidParameters(
    //       packageName: 'com.wishooo.app',
    //       minimumVersion: 1,
    //   ),
    //   iosParameters: new IosParameters(
    //       bundleId: 'com.wishooo.app',
    //       minimumVersion: '0.0.0',
    //       appStoreId: '1451174441',
    //   ),
    //   // googleAnalyticsParameters: new GoogleAnalyticsParameters(
    //   //     campaign: 'example-promo',
    //   //     medium: 'social',
    //   //     source: 'orkut',
    //   // ),
    //   itunesConnectAnalyticsParameters: new ItunesConnectAnalyticsParameters(
    //     providerToken: '123456',        // TODO: to be added after deployment
    //     campaignToken: 'example-promo', // TODO: to be added after deployment
    //   ),
    //   socialMetaTagParameters:  new SocialMetaTagParameters(
    //     title: title,
    //     description: message,
    //   ),
    // );

    // final Uri dynamicUrl = await parameters.buildUrl();
    // print(dynamicUrl.toString());
    
    // final ShortDynamicLink shortenedLink = await DynamicLinkParameters.shortenUrl(dynamicUrl);
    // var shortUrl = shortenedLink.shortUrl.toString();
    // print(shortUrl);
    // return shortUrl;
  }

}

==> tecfy_core_package-0.1.65.tar.gz: lib/services/dynamic_links.dart <==
part of tecfy_core_client_package;

class DynamicLinksService {
  static init() {}

  static Future shareString(String message) async {
    // return Share.share(message);
  }

  static Future<String> retrieveDynamicLink() async {
    // final PendingDynamicLinkData data = await FirebaseDynamicLinks.instance.retrieveDynamicLink();
    // final Uri deepLink = data?.link;

    // return deepLink.path;
    // if (deepLink != null) {
    //   Navigator.pushNamed(context, deepLink.path); // deeplink.path == '/helloworld'
    // }
    return "";
  }

  static Future<String> generateShortLinkList(
      String title, String message, String type, String id) async {
    return "";
    // final DynamicLinkParameters parameters = new DynamicLinkParameters(
    //   domain: 'wis.page.link',
    //   link: Uri.parse('https://www.wishooo.com/list?id=$id'),
    //   androidParameters: new AndroidParameters(
    //       packageName: 'com.wishooo.app',
    //       minimumVersion: 1,
    //   ),
    //   iosParameters: new IosParameters(
    //       bundleId: 'com.wishooo.app',
    //       minimumVersion: '0.0.0',
    //       appStoreId: '1451174441',
    //   ),
    //   // googleAnalyticsParameters: new GoogleAnalyticsParameters(
    //   //     campaign: 'example-promo',
    //   //     medium: 'social',
    //   //     source: 'orkut',
    //   // ),
    //   itunesConnectAnalyticsParameters: new ItunesConnectAnalyticsParameters(
    //     providerToken: '123456',        // TODO: to be added after deployment
    //     campaignToken: 'example-promo', // TODO: to be added after deployment
    //   ),
    //   socialMetaTagParameters:  new SocialMetaTagParameters(
    //     title: title,
    //     description: message,
    //   ),
    // );

    // final Uri dynamicUrl = await parameters.buildUrl();
    // print(dynamicUrl.toString());

    // final ShortDynamicLink shortenedLink = await DynamicLinkParameters.shortenUrl(dynamicUrl);
    // var shortUrl = shortenedLink.shortUrl.toString();
    // print(shortUrl);
    // return shortUrl;
  }
}
